#Written by Chris Rackauckas
#Based off of the BLMR program by John K. Kruschke

graphics.off()          # Clears all graphical displays.
rm(list=ls(all=TRUE))   # Removes all variables from memory!
# Get the Bayesian functions into R's working memory:
source("BRMLR.R")


############################################ Non Robust #########################################################

# Load the data files into R:
Regression1 = read.csv( file="Regression1.csv" )
Regression2 = read.csv( file="Regression2.csv" )
Regression3 = read.csv( file="Regression3.csv" )
Regression4 = read.csv( file="Regression4.csv" )
# Important: The matrix dataMat must have the criterion y in its first column, 
# and the predictors in the subsequent columns!

# Run the Bayesian analysis and put the results in variable named mcmcChain:
mcmcChain1 = BMLRmcmc( Regression1 )
mcmcChain2 = BMLRmcmc( Regression2 )
mcmcChain3 = BMLRmcmc( Regression3 )
mcmcChain4 = BMLRmcmc( Regression4 )

# Plot the posterior distribution and put summary in variable named postInfo:
postInfo1 = BMLRplot( mcmcChain1, names=c("YL1","YL2","MRes","MResL1","MResL2","MResL3") ) 
postInfo2 = BMLRplot( mcmcChain2, names=c("YL1","YL2","PRes","PResL1","PResL2","PResL3") ) 
postInfo3 = BMLRplot( mcmcChain3, names=c("YL1","YL2","MRes","MResL1","MResL2","MResL3","DBanks","DBanksL1","DFail","DFailL1") ) 
postInfo4 = BMLRplot( mcmcChain4, names=c("YL1","YL2","PRes","PResL1","PResL2","PResL3","DBanks","DBanksL1","DFail","DFailL1") ) 

# Display the summary on the console:
show(postInfo1)
show(postInfo2)
show(postInfo3)
show(postInfo4)

############################################ Robust ################################################################

# Run the Bayesian analysis and put the results in variable named mcmcChain:
mcmcChain1R = BRMLRmcmc( Regression1 )
mcmcChain2R = BRMLRmcmc( Regression2 )
mcmcChain3R = BRMLRmcmc( Regression3 )
mcmcChain4R = BRMLRmcmc( Regression4 )

# Plot the posterior distribution and put summary in variable named postInfo:
# credMass sets the size of the HDI

postInfo1R = BMLRplot( mcmcChain1R, names=c("YL1","YL2","MRes","MResL1","MResL2","MResL3"),credMass=.999, robust=TRUE) 
postInfo2R = BMLRplot( mcmcChain2R, names=c("YL1","YL2","PRes","PResL1","PResL2","PResL3"),credMass=.95, robust=TRUE) 
postInfo3R = BMLRplot( mcmcChain3R, names=c("YL1","YL2","MRes","MResL1","MResL2","MResL3","DBanks","DBanksL1","DFail","DFailL1"),credMass=.95, robust=TRUE ) 
postInfo4R = BMLRplot( mcmcChain4R, names=c("YL1","YL2","PRes","PResL1","PResL2","PResL3","DBanks","DBanksL1","DFail","DFailL1"),credMass=.95, robust=TRUE ) 

# Display the summary on the console:
show(postInfo1R)
show(postInfo2R)
show(postInfo3R)
show(postInfo4R)